@@ -4,7 +4,7 @@ use std::sync::Arc;
 use crate::{
     array::{Array, MutableArray, TryExtend, TryPush},
     bitmap::MutableBitmap,
-    datatypes::DataType,
+    datatypes::{DataType, PhysicalType},
     error::Result,
     trusted_len::TrustedLen,
 };
@@ -13,15 +13,22 @@ use super::BooleanArray;
 
 /// The Arrow's equivalent to `Vec<Option<bool>>`, but with `1/16` of its size.
 /// Converting a [`MutableBooleanArray`] into a [`BooleanArray`] is `O(1)`.
+/// # Implementation
+/// This struct does not allocate a validity until one is required (i.e. push a null to it).
 #[derive(Debug)]
 pub struct MutableBooleanArray {
+    data_type: DataType,
     values: MutableBitmap,
     validity: Option<MutableBitmap>,
 }
 
 impl From<MutableBooleanArray> for BooleanArray {
     fn from(other: MutableBooleanArray) -> Self {
-        BooleanArray::from_data(other.values.into(), other.validity.map(|x| x.into()))
+        BooleanArray::from_data(
+            other.data_type,
+            other.values.into(),
+            other.validity.map(|x| x.into()),
+        )
     }
 }
 
@@ -39,17 +46,21 @@ impl Default for MutableBooleanArray {
 }
 
 impl MutableBooleanArray {
+    /// Creates an new empty [`MutableBooleanArray`].
     pub fn new() -> Self {
         Self::with_capacity(0)
     }
 
+    /// Creates an new [`MutableBooleanArray`] with a capacity of values.
     pub fn with_capacity(capacity: usize) -> Self {
         Self {
+            data_type: DataType::Boolean,
             values: MutableBitmap::with_capacity(capacity),
             validity: None,
         }
     }
 
+    /// Reserves `additional` slots.
     pub fn reserve(&mut self, additional: usize) {
         self.values.reserve(additional);
         if let Some(x) = self.validity.as_mut() {
@@ -57,10 +68,23 @@ impl MutableBooleanArray {
         }
     }
 
-    pub fn from_data(values: MutableBitmap, validity: Option<MutableBitmap>) -> Self {
-        Self { values, validity }
+    /// Canonical method to create a new [`MutableBooleanArray`].
+    pub fn from_data(
+        data_type: DataType,
+        values: MutableBitmap,
+        validity: Option<MutableBitmap>,
+    ) -> Self {
+        if data_type.to_physical_type() != PhysicalType::Boolean {
+            panic!("MutableBooleanArray can only be initialized with DataType::Boolean")
+        }
+        Self {
+            data_type,
+            values,
+            validity,
+        }
     }
 
+    /// Pushes a new entry to [`MutableBooleanArray`].
     pub fn push(&mut self, value: Option<bool>) {
         match value {
             Some(value) => {
@@ -130,7 +154,11 @@ impl MutableBooleanArray {
     /// Creates a new [`MutableBooleanArray`] from an [`TrustedLen`] of `bool`.
     #[inline]
     pub fn from_trusted_len_values_iter<I: TrustedLen<Item = bool>>(iterator: I) -> Self {
-        Self::from_data(MutableBitmap::from_trusted_len_iter(iterator), None)
+        Self::from_data(
+            DataType::Boolean,
+            MutableBitmap::from_trusted_len_iter(iterator),
+            None,
+        )
     }
 
     /// Creates a new [`MutableBooleanArray`] from a slice of `bool`.
@@ -159,7 +187,7 @@ impl MutableBooleanArray {
             None
         };
 
-        Self::from_data(values, validity)
+        Self::from_data(DataType::Boolean, values, validity)
     }
 
     /// Creates a [`BooleanArray`] from a [`TrustedLen`].
@@ -192,7 +220,7 @@ impl MutableBooleanArray {
             None
         };
 
-        Ok(Self::from_data(values, validity))
+        Ok(Self::from_data(DataType::Boolean, values, validity))
     }
 
     /// Creates a [`BooleanArray`] from a [`TrustedLen`].
@@ -297,7 +325,7 @@ impl<Ptr: std::borrow::Borrow<Option<bool>>> FromIterator<Ptr> for MutableBoolea
             })
             .collect();
 
-        MutableBooleanArray::from_data(values, validity.into())
+        MutableBooleanArray::from_data(DataType::Boolean, values, validity.into())
     }
 }
 
@@ -312,13 +340,14 @@ impl MutableArray for MutableBooleanArray {
 
     fn as_arc(&mut self) -> Arc<dyn Array> {
         Arc::new(BooleanArray::from_data(
+            self.data_type.clone(),
             std::mem::take(&mut self.values).into(),
             std::mem::take(&mut self.validity).map(|x| x.into()),
         ))
     }
 
     fn data_type(&self) -> &DataType {
-        &DataType::Boolean
+        &self.data_type
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
