@@ -1,7 +1,7 @@
 use std::sync::Arc;
 
 use crate::{
-    array::{Array, MutableArray, Offset, TryExtend},
+    array::{Array, MutableArray, Offset, TryExtend, TryPush},
     bitmap::MutableBitmap,
     buffer::MutableBuffer,
     datatypes::{DataType, Field},
@@ -67,13 +67,25 @@ where
 {
     fn try_extend<II: IntoIterator<Item = Option<I>>>(&mut self, iter: II) -> Result<()> {
         for items in iter {
-            if let Some(items) = items {
-                let values = self.mut_values();
-                values.try_extend(items)?;
-                self.try_push_valid()?;
-            } else {
-                self.push_null();
-            }
+            self.try_push(items)?;
+        }
+        Ok(())
+    }
+}
+
+impl<O, M, I, T> TryPush<Option<I>> for MutableListArray<O, M>
+where
+    O: Offset,
+    M: MutableArray + TryExtend<Option<T>>,
+    I: IntoIterator<Item = Option<T>>,
+{
+    fn try_push(&mut self, item: Option<I>) -> Result<()> {
+        if let Some(items) = item {
+            let values = self.mut_values();
+            values.try_extend(items)?;
+            self.try_push_valid()?;
+        } else {
+            self.push_null();
         }
         Ok(())
     }
@@ -190,42 +202,3 @@ impl<O: Offset, M: MutableArray + 'static> MutableArray for MutableListArray<O,
         self.push_null()
     }
 }
-
-#[cfg(test)]
-mod tests {
-    use crate::{
-        array::{primitive::MutablePrimitiveArray, PrimitiveArray},
-        bitmap::Bitmap,
-        buffer::Buffer,
-    };
-
-    use super::*;
-
-    #[test]
-    fn basics() {
-        let data = vec![
-            Some(vec![Some(1i32), Some(2), Some(3)]),
-            None,
-            Some(vec![Some(4), None, Some(6)]),
-        ];
-
-        let mut array = MutableListArray::<i32, MutablePrimitiveArray<i32>>::new();
-        array.try_extend(data).unwrap();
-        let array: ListArray<i32> = array.into();
-
-        let values = PrimitiveArray::<i32>::from_data(
-            DataType::Int32,
-            Buffer::from([1, 2, 3, 4, 0, 6]),
-            Some(Bitmap::from([true, true, true, true, false, true])),
-        );
-
-        let data_type = ListArray::<i32>::default_datatype(DataType::Int32);
-        let expected = ListArray::<i32>::from_data(
-            data_type,
-            Buffer::from([0, 3, 3, 6]),
-            Arc::new(values),
-            Some(Bitmap::from([true, false, true])),
-        );
-        assert_eq!(expected, array);
-    }
-}
