@@ -4,13 +4,13 @@ use crate::{
     types::{NativeType, NaturalDataType},
 };
 use crate::{
-    array::{Offset, Utf8Array},
+    array::{BinaryArray, Offset, Utf8Array},
     error::Result,
 };
 
 pub(super) fn boolean_to_primitive_dyn<T>(array: &dyn Array) -> Result<Box<dyn Array>>
 where
-    T: NativeType + NaturalDataType + num::One,
+    T: NativeType + NaturalDataType + num_traits::One,
 {
     let array = array.as_any().downcast_ref().unwrap();
     Ok(Box::new(boolean_to_primitive::<T>(array)))
@@ -19,7 +19,7 @@ where
 /// Casts the [`BooleanArray`] to a [`PrimitiveArray`].
 pub fn boolean_to_primitive<T>(from: &BooleanArray) -> PrimitiveArray<T>
 where
-    T: NativeType + NaturalDataType + num::One,
+    T: NativeType + NaturalDataType + num_traits::One,
 {
     let iter = from
         .values()
@@ -40,3 +40,14 @@ pub(super) fn boolean_to_utf8_dyn<O: Offset>(array: &dyn Array) -> Result<Box<dy
     let array = array.as_any().downcast_ref().unwrap();
     Ok(Box::new(boolean_to_utf8::<O>(array)))
 }
+
+/// Casts the [`BooleanArray`] to a [`BinaryArray`], casting trues to `"1"` and falses to `"0"`
+pub fn boolean_to_binary<O: Offset>(from: &BooleanArray) -> BinaryArray<O> {
+    let iter = from.values().iter().map(|x| if x { b"1" } else { b"0" });
+    BinaryArray::from_trusted_len_values_iter(iter)
+}
+
+pub(super) fn boolean_to_binary_dyn<O: Offset>(array: &dyn Array) -> Result<Box<dyn Array>> {
+    let array = array.as_any().downcast_ref().unwrap();
+    Ok(Box::new(boolean_to_binary::<O>(array)))
+}
