@@ -2,18 +2,16 @@ use std::convert::TryFrom;
 
 use chrono::Datelike;
 
-use crate::{
-    array::*,
-    buffer::Buffer,
-    datatypes::{DataType, TimeUnit},
-    types::NativeType,
-};
+use crate::{array::*, buffer::Buffer, datatypes::DataType, types::NativeType};
 use crate::{
     error::{ArrowError, Result},
-    temporal_conversions::EPOCH_DAYS_FROM_CE,
+    temporal_conversions::{
+        utf8_to_naive_timestamp_ns as utf8_to_naive_timestamp_ns_,
+        utf8_to_timestamp_ns as utf8_to_timestamp_ns_, EPOCH_DAYS_FROM_CE,
+    },
 };
 
-use super::utf8_to_timestamp_ns_scalar;
+const RFC3339: &str = "%Y-%m-%dT%H:%M:%S%.f%:z";
 
 /// Casts a [`Utf8Array`] to a [`PrimitiveArray`], making any uncastable value a Null.
 pub fn utf8_to_primitive<O: Offset, T>(from: &Utf8Array<O>, to: &DataType) -> PrimitiveArray<T>
@@ -92,33 +90,55 @@ pub fn utf8_to_dictionary<O: Offset, K: DictionaryKey>(
     Ok(array.into())
 }
 
-pub(super) fn utf8_to_timestamp_ns_dyn<O: Offset>(from: &dyn Array) -> Result<Box<dyn Array>> {
+pub(super) fn utf8_to_naive_timestamp_ns_dyn<O: Offset>(
+    from: &dyn Array,
+) -> Result<Box<dyn Array>> {
     let from = from.as_any().downcast_ref().unwrap();
-    Ok(Box::new(utf8_to_timestamp_ns::<O>(from)))
+    Ok(Box::new(utf8_to_naive_timestamp_ns::<O>(from)))
 }
 
-/// The array version of [`utf8_to_timestamp_ns_scalar`].
-pub fn utf8_to_timestamp_ns<O: Offset>(from: &Utf8Array<O>) -> PrimitiveArray<i64> {
-    let iter = from
-        .iter()
-        .map(|x| x.and_then(|x| utf8_to_timestamp_ns_scalar(x).ok()));
-    PrimitiveArray::<i64>::from_trusted_len_iter(iter)
-        .to(DataType::Timestamp(TimeUnit::Nanosecond, None))
+/// [`crate::temporal_conversions::utf8_to_timestamp_ns`] applied for RFC3339 formatting
+pub fn utf8_to_naive_timestamp_ns<O: Offset>(from: &Utf8Array<O>) -> PrimitiveArray<i64> {
+    utf8_to_naive_timestamp_ns_(from, RFC3339)
+}
+
+pub(super) fn utf8_to_timestamp_ns_dyn<O: Offset>(
+    from: &dyn Array,
+    timezone: String,
+) -> Result<Box<dyn Array>> {
+    let from = from.as_any().downcast_ref().unwrap();
+    utf8_to_timestamp_ns::<O>(from, timezone)
+        .map(Box::new)
+        .map(|x| x as Box<dyn Array>)
+}
+
+/// [`crate::temporal_conversions::utf8_to_timestamp_ns`] applied for RFC3339 formatting
+pub fn utf8_to_timestamp_ns<O: Offset>(
+    from: &Utf8Array<O>,
+    timezone: String,
+) -> Result<PrimitiveArray<i64>> {
+    utf8_to_timestamp_ns_(from, RFC3339, timezone)
 }
 
 pub fn utf8_to_large_utf8(from: &Utf8Array<i32>) -> Utf8Array<i64> {
+    let data_type = Utf8Array::<i64>::default_data_type();
     let values = from.values().clone();
     let offsets = from.offsets().iter().map(|x| *x as i64);
     let offsets = Buffer::from_trusted_len_iter(offsets);
-    unsafe { Utf8Array::<i64>::from_data_unchecked(offsets, values, from.validity().clone()) }
+    unsafe {
+        Utf8Array::<i64>::from_data_unchecked(data_type, offsets, values, from.validity().clone())
+    }
 }
 
 pub fn utf8_large_to_utf8(from: &Utf8Array<i64>) -> Result<Utf8Array<i32>> {
+    let data_type = Utf8Array::<i32>::default_data_type();
     let values = from.values().clone();
     let _ =
         i32::try_from(*from.offsets().last().unwrap()).map_err(ArrowError::from_external_error)?;
 
     let offsets = from.offsets().iter().map(|x| *x as i32);
     let offsets = Buffer::from_trusted_len_iter(offsets);
-    Ok(unsafe { Utf8Array::<i32>::from_data_unchecked(offsets, values, from.validity().clone()) })
+    Ok(unsafe {
+        Utf8Array::<i32>::from_data_unchecked(data_type, offsets, values, from.validity().clone())
+    })
 }
