@@ -31,9 +31,12 @@ mod utils;
 pub mod window;
 
 #[cfg(feature = "regex")]
+#[cfg_attr(docsrs, doc(cfg(feature = "regex")))]
 pub mod like;
 #[cfg(feature = "regex")]
+#[cfg_attr(docsrs, doc(cfg(feature = "regex")))]
 pub mod regex_match;
 
 #[cfg(feature = "merge_sort")]
+#[cfg_attr(docsrs, doc(cfg(feature = "merge_sort")))]
 pub mod merge_sort;
