@@ -21,6 +21,7 @@ use regex::Regex;
 
 use super::utils::{combine_validities, unary_utf8_boolean};
 use crate::array::{BooleanArray, Offset, Utf8Array};
+use crate::datatypes::DataType;
 use crate::error::{ArrowError, Result};
 use crate::{array::*, bitmap::Bitmap};
 
@@ -59,7 +60,11 @@ pub fn regex_match<O: Offset>(values: &Utf8Array<O>, regex: &Utf8Array<O>) -> Re
     });
     let new_values = Bitmap::try_from_trusted_len_iter(iterator)?;
 
-    Ok(BooleanArray::from_data(new_values, validity))
+    Ok(BooleanArray::from_data(
+        DataType::Boolean,
+        new_values,
+        validity,
+    ))
 }
 
 /// Regex matches
@@ -78,62 +83,3 @@ pub fn regex_match_scalar<O: Offset>(values: &Utf8Array<O>, regex: &str) -> Resu
         .map_err(|e| ArrowError::InvalidArgumentError(format!("Unable to compile regex: {}", e)))?;
     Ok(unary_utf8_boolean(values, |x| regex.is_match(x)))
 }
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-
-    fn test_generic<O: Offset, F: Fn(&Utf8Array<O>, &Utf8Array<O>) -> Result<BooleanArray>>(
-        lhs: Vec<&str>,
-        pattern: Vec<&str>,
-        op: F,
-        expected: Vec<bool>,
-    ) {
-        let lhs = Utf8Array::<O>::from_slice(lhs);
-        let pattern = Utf8Array::<O>::from_slice(pattern);
-        let expected = BooleanArray::from_slice(expected);
-        let result = op(&lhs, &pattern).unwrap();
-        assert_eq!(result, expected);
-    }
-
-    fn test_generic_scalar<O: Offset, F: Fn(&Utf8Array<O>, &str) -> Result<BooleanArray>>(
-        lhs: Vec<&str>,
-        pattern: &str,
-        op: F,
-        expected: Vec<bool>,
-    ) {
-        let lhs = Utf8Array::<O>::from_slice(lhs);
-        let expected = BooleanArray::from_slice(expected);
-        let result = op(&lhs, pattern).unwrap();
-        assert_eq!(result, expected);
-    }
-
-    #[test]
-    fn test_like() {
-        test_generic::<i32, _>(
-            vec![
-                "arrow", "arrow", "arrow", "arrow", "arrow", "arrows", "arrow",
-            ],
-            vec!["arrow", "^ar", "ro", "foo", "arr$", "arrow.", "arrow."],
-            regex_match,
-            vec![true, true, true, false, false, true, false],
-        )
-    }
-
-    #[test]
-    fn test_like_scalar() {
-        test_generic_scalar::<i32, _>(
-            vec!["arrow", "parquet", "datafusion", "flight"],
-            "ar",
-            regex_match_scalar,
-            vec![true, true, false, false],
-        );
-
-        test_generic_scalar::<i32, _>(
-            vec!["arrow", "parquet", "datafusion", "flight"],
-            "^ar",
-            regex_match_scalar,
-            vec![true, false, false, false],
-        )
-    }
-}
